/*
* Fabric3
* Copyright (c) 2009-2011 Metaform Systems
*
* Fabric3 is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as
* published by the Free Software Foundation, either version 3 of
* the License, or (at your option) any later version, with the
* following exception:
*
* Linking this software statically or dynamically with other
* modules is making a combined work based on this software.
* Thus, the terms and conditions of the GNU General Public
* License cover the whole combination.
*
* As a special exception, the copyright holders of this software
* give you permission to link this software with independent
* modules to produce an executable, regardless of the license
* terms of these independent modules, and to copy and distribute
* the resulting executable under terms of your choice, provided
* that you also meet, for each linked independent module, the
* terms and conditions of the license of that module. An
* independent module is a module which is not derived from or
* based on this software. If you modify this software, you may
* extend this exception to your version of the software, but
* you are not obligated to do so. If you do not wish to do so,
* delete this exception statement from your version.
*
* Fabric3 is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty
* of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
* See the GNU General Public License for more details.
*
* You should have received a copy of the
* GNU General Public License along with Fabric3.
* If not, see <http://www.gnu.org/licenses/>.
*/
package org.fabric3.spi.allocator;

import org.fabric3.spi.model.instance.LogicalChannel;
import org.fabric3.spi.model.instance.LogicalComponent;
import org.fabric3.spi.model.instance.LogicalResource;
import org.fabric3.spi.plan.DeploymentPlan;

/**
 * Allocates components and channels to a zone. If the component is a composite, allocation will be performed recursively.
 *
 * @version $Rev: 9763 $ $Date: 2011-01-03 00:48:06 +0000 (Mon, 03 Jan 2011) $
 */
public interface Allocator {

    /**
     * Allocates a component. Composites are recursed and their children are allocated.
     *
     * @param component the component to allocate
     * @param plan      the deployment plan containing zone mappings
     * @throws AllocationException if an error during allocation occurs
     */
    void allocate(LogicalComponent<?> component, DeploymentPlan plan) throws AllocationException;

    /**
     * Allocates a channel. Composites are recursed and their children are allocated.
     *
     * @param channel the channel to allocate
     * @param plan    the deployment plan containing zone mappings
     * @throws AllocationException if an error during allocation occurs
     */
    void allocate(LogicalChannel channel, DeploymentPlan plan) throws AllocationException;

    /**
     * Allocates a resource. Composites are recursed and their children are allocated.
     *
     * @param resource the resource to allocate
     * @param plan     the deployment plan containing zone mappings
     * @throws AllocationException if an error during allocation occurs
     */
    void allocate(LogicalResource<?> resource, DeploymentPlan plan) throws AllocationException;

}
